#!/usr/bin/env python

# Copyright (c) 2014-2015 Japan Atomic Energy Agency
#
#    angel2vtk is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation;
#    version 2.1 of the License.
#
#    This software is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this software; if not, write to the Free Software
#    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
#
# Author:
#       Kazuyoshi Furutaka <furutaka.kazuyoshi@jaea.go.jp>

"""The ``--install-script`` for the windows installer to create shortcuts.

This script will be run at installation time on the target system
after all the files have been copied (**NO** care will be taken on
uninstallation), and create shorcuts on the Desktop as well as in
the Start Menu.

This script is largely based on `an article`_ found on the net.

.. _`an article`: http://stackoverflow.com/questions/24841130/how-to-create-a-shortcut-in-startmenu-using-setuptools-windows-installer

.. moduleauthor:: Kazuyoshi Furutaka <furutaka.kazuyoshi@jaea.go.jp>
.. module:: setup.py
    :platform: Windows (make **NO SENSE** on other platform)
    :synopsis: The post-install script for angel2vtk on Windows platform.
"""

import sys
from os.path import expanduser, join

progname = "angel2vtk"

pyw_executable = join(sys.prefix, "Scripts", "%s.pyw.exe" % progname)
shortcut_filename = "%s.lnk" % progname

if sys.platform == "win32": # MAKE SENSE ONLY ON WINDOZE
        # Get Windows special paths to the desktop and start menu
        desktop_path = get_special_folder_path("CSIDL_DESKTOPDIRECTORY")
        startmenu_path = get_special_folder_path("CSIDL_STARTMENU")
        if sys.argv[1] == "-install":
                # Create shortcuts on the Desktop as well as in the Start Menu
                #   create_shortcut(target, description,
                #     filename[, arguments[, workdir[, iconpath[, iconindex]]]])
                # target: the path to the program to be started by the shortcut
                # description: the description of the shortcut
                # filename: the title of the shortcut that the user will see
                # arguments: specifies the command line arguments, if any
                #  workdir: the working directory for the program
                for path in [desktop_path, startmenu_path]:
                        create_shortcut(pyw_executable,progname,
                                        join(path,shortcut_filename))
                        file_created(join(path,shortcut_filename))
